==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/ZebranieZtoPracownikKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.enums.TypUczestnictwaPracownika;
import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class ZebranieZtoPracownikKey extends GenericDPSObject {
    /**
     * ZEBRANIE_ZTO_PRACOWNIK.ZEBRANIE_ZTO_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zebranieZtoId;

    /**
     * ZEBRANIE_ZTO_PRACOWNIK.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pracownikId;

    /**
     * ZEBRANIE_ZTO_PRACOWNIK.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypUczestnictwaPracownika typ;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZEBRANIE_ZTO_PRACOWNIK.ZEBRANIE_ZTO_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZebranieZtoId() {
        return zebranieZtoId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * ZEBRANIE_ZTO_PRACOWNIK.ZEBRANIE_ZTO_ID
     *
     * @param zebranieZtoId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZebranieZtoId(Long zebranieZtoId) {
        this.zebranieZtoId = zebranieZtoId;
    }

    /**
     * @return ZEBRANIE_ZTO_PRACOWNIK.PRACOWNIK_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPracownikId() {
        return pracownikId;
    }

    /**
     * ZEBRANIE_ZTO_PRACOWNIK.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return ZEBRANIE_ZTO_PRACOWNIK.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypUczestnictwaPracownika getTyp() {
        return typ;
    }

    /**
     * ZEBRANIE_ZTO_PRACOWNIK.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypUczestnictwaPracownika typ) {
        this.typ = typ;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZebranieZtoPracownikKey other = (ZebranieZtoPracownikKey) that;
        return (this.getZebranieZtoId() == null ? other.getZebranieZtoId() == null : this.getZebranieZtoId().equals(other.getZebranieZtoId()))
            && (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getZebranieZtoId() == null) ? 0 : getZebranieZtoId().hashCode());
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", zebranieZtoId=").append(zebranieZtoId);
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", typ=").append(typ);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/ZebranieZtoPracownikKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.enums.TypUczestnictwaPracownika;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class ZebranieZtoPracownikKey extends GenericDPSObject {
    /**
     * ZEBRANIE_ZTO_PRACOWNIK.ZEBRANIE_ZTO_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zebranieZtoId;

    /**
     * ZEBRANIE_ZTO_PRACOWNIK.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pracownikId;

    /**
     * ZEBRANIE_ZTO_PRACOWNIK.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypUczestnictwaPracownika typ;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZEBRANIE_ZTO_PRACOWNIK.ZEBRANIE_ZTO_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZebranieZtoId() {
        return zebranieZtoId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * ZEBRANIE_ZTO_PRACOWNIK.ZEBRANIE_ZTO_ID
     *
     * @param zebranieZtoId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZebranieZtoId(Long zebranieZtoId) {
        this.zebranieZtoId = zebranieZtoId;
    }

    /**
     * @return ZEBRANIE_ZTO_PRACOWNIK.PRACOWNIK_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPracownikId() {
        return pracownikId;
    }

    /**
     * ZEBRANIE_ZTO_PRACOWNIK.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return ZEBRANIE_ZTO_PRACOWNIK.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypUczestnictwaPracownika getTyp() {
        return typ;
    }

    /**
     * ZEBRANIE_ZTO_PRACOWNIK.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypUczestnictwaPracownika typ) {
        this.typ = typ;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZebranieZtoPracownikKey other = (ZebranieZtoPracownikKey) that;
        return (this.getZebranieZtoId() == null ? other.getZebranieZtoId() == null : this.getZebranieZtoId().equals(other.getZebranieZtoId()))
            && (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getZebranieZtoId() == null) ? 0 : getZebranieZtoId().hashCode());
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", zebranieZtoId=").append(zebranieZtoId);
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", typ=").append(typ);
        sb.append("]");
        return sb.toString();
    }
}
